---
title: Linear Layers
---

::: klax.nn.Linear
    options:
        members:
            - __init__
            - __call__

---

::: klax.nn.InputSplitLinear
    options:
        members:
            - __init__
            - __call__